import random
import string

import quantumrandom

BLOCK_SIZE = 128
MAX_LENGTH = 1024
DEFAULT_NUMBER = 1
DEFAULT_LENGTH = 24
DEFAULT_POPULATION = string.ascii_lowercase + string.ascii_uppercase + string.digits


def rand(population = DEFAULT_POPULATION, number = DEFAULT_NUMBER, length = DEFAULT_LENGTH):
    quantum_data = quantumrandom.get_data(
        data_type='hex16',
        block_size=BLOCK_SIZE,
        array_length=number,
    )

    data = []

    for quantum_hex in quantum_data:
        random.seed(quantum_hex)
        data.append("".join([random.choice(population) for _ in range(length)]))

    return data



import sys
import string
import argparse
import quantum_sg

BLOCK_SIZE = 128
MAX_LENGTH = 1024


def main():
    parser = argparse.ArgumentParser(
        description="A command line tool that generates a cryptographically "
                    "secure quantum-level secrets using ANU QRNG."
    )

    parser.add_argument(
        "-n",
        "--number",
        type=int,
        default=1,
        help="The number of secrets to be generated (default is 1)",
    )

    parser.add_argument(
        "-l",
        "--length",
        type=int,
        default=24,
        help="the length of each generated secret (default is 24)",
    )

    parser.add_argument(
        "-wd",
        "--digits",
        default=True,
        action=argparse.BooleanOptionalAction,
        help="include digits in the generated secrets (default is True)",
    )

    parser.add_argument(
        "-wl",
        "--lowercase",
        default=True,
        action=argparse.BooleanOptionalAction,
        help="include lowercase characters in the generated secrets (default is True)",
    )

    parser.add_argument(
        "-wu",
        "--uppercase",
        default=True,
        action=argparse.BooleanOptionalAction,
        help="include uppercase characters in the generated secrets (default is True)",
    )

    parser.add_argument(
        "-wp",
        "--punctuation",
        default=False,
        action=argparse.BooleanOptionalAction,
        help="include punctuation characters in the generated secrets (default is False)",
    )

    args = parser.parse_args()
    if args.length > MAX_LENGTH or args.length <= 0:
        sys.stdout.write(f'Length must be a non-negative integer and less than or equal to {MAX_LENGTH} \n')
        return

    population = ""

    if args.digits:
        population += string.digits

    if args.lowercase:
        population += string.ascii_lowercase

    if args.uppercase:
        population += string.ascii_uppercase

    if args.punctuation:
        population += string.punctuation

    for phrase in quantum_sg.rand(population=population, number=args.number, length=args.length):
        sys.stdout.write(phrase + "\n")


if __name__ == "__main__":
    main()



from setuptools import setup
import os

VERSION = '0.1.0'
PROJECT = 'quantum-sg'
AUTHOR = u'Alexander Shelepenok'
AUTHOR_EMAIL = u'alxshelepenok@gmail.com'
URL = 'https://github.com/alxshelepenok/quantum-sg'
DESCRIPTION = "A command line tool that generates a cryptographically secure quantum-level secrets using ANU QRNG."


def read_file(file_name):
    file_path = os.path.join(
        os.path.dirname(__file__),
        file_name
    )
    return open(file_path).read()


setup(
    url=URL,
    name=PROJECT,
    author=AUTHOR,
    version=VERSION,
    description=DESCRIPTION,
    author_email=AUTHOR_EMAIL,
    long_description=read_file('README.md'),
    long_description_content_type="text/markdown",
    zip_safe=True,
    include_package_data=True,
    packages=['quantum_sg'],
    keywords='quantum random secrets',
    install_requires=['quantumrandom'],
    entry_points="""
        [console_scripts]
        quantum-sg = quantum_sg.quantum_sg:main
      """,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
)
